@@ -712,7 +712,7 @@ static Boolean FunChangeList (
     text[i] = 0;
 
     /* change list */
-    XawListChange( arg->sel->list, text, 0, 0, True );
+    XawListChange( arg->sel->list, (const char **)text, 0, 0, True );
 
     /* clear old text */
     for ( i = 0;  arg->sel->text[i];  i++ )
@@ -1000,7 +1000,7 @@ static Boolean FunShowDialog (
 #       endif
     }
 
-    /* unkown dialog */
+    /* unknown dialog */
     else
 	return ANSWER_GAP("esd","illegal popup dialog ",arg->iargs[0],0,0);
 
@@ -2020,7 +2020,7 @@ static XtActionsRec PrivateActions[] =
 
 /****************************************************************************
 **
-*F  InitXCMDS()	. . . . . . . . . . . . . . .  initalize all global variables
+*F  InitXCMDS()	. . . . . . . . . . . . . . .  initialize all global variables
 */
 void InitXCMDS ()
 {
